@@ -4,11 +4,11 @@
   For Tux Paint
   List of available titles
 
-  Copyright (c) 2002 by Bill Kendrick
+  Copyright (c) 2004 by Bill Kendrick
   bill@newbreedsoftware.com
   http://www.newbreedsoftware.com/tuxpaint/
 
-  June 14, 2002 - October 19, 2002
+  June 14, 2002 - September 14, 2004
 */
 
 
@@ -21,6 +21,7 @@ enum {
   TITLE_TOOLS,
   TITLE_COLORS,
   TITLE_BRUSHES,
+  TITLE_ERASERS,
   TITLE_STAMPS,
   TITLE_SHAPES,
   TITLE_LETTERS,
@@ -37,6 +38,7 @@ char * title_names[NUM_TITLES] = {
   gettext_noop("Tools"),
   gettext_noop("Colors"),
   gettext_noop("Brushes"),
+  gettext_noop("Erasers"),
   gettext_noop("Stamps"),
   gettext_noop("Shapes"),
   gettext_noop("Letters"),
