@@ -61,24 +61,24 @@ char * tool_names[NUM_TOOLS] = {
 char * tool_tips[NUM_TOOLS] = {
   gettext_noop("Pick a color and a brush shape to draw with."),
   gettext_noop("Pick a picture to stamp around your drawing."),
-  gettext_noop("Click to start drawing a line.  Let go to complete it."),
-  gettext_noop("Pick a shape. Click to pick the center, drag, then let go when it is the size you want.  Move around to rotate it, and click to draw it."),
-  gettext_noop("Choose a style of text.  Click on your drawing and you can start typing."),
+  gettext_noop("Click to start drawing a line. Let go to complete it."),
+  gettext_noop("Pick a shape. Click to pick the center, drag, then let go when it is the size you want. Move around to rotate it, and click to draw it."),
+  gettext_noop("Choose a style of text. Click on your drawing and you can start typing."),
   gettext_noop("Pick a magical effect to use on your drawing!"),
   /* Undo */ gettext_noop("Undo!"),
   /* Redo */ gettext_noop("Redo!"),
   /* Eraser */ gettext_noop("Eraser!"),
   /* New */ gettext_noop("You now have a blank sheet to draw on!"),
-  /* Open */ gettext_noop("Open..."),
+  /* Open */ gettext_noop("Open…"),
   /* Save */ gettext_noop("Your image has been saved!"),
-  /* Print */ gettext_noop("Printing..."),
+  /* Print */ gettext_noop("Printing…"),
   /* Quit */ gettext_noop("Bye bye!")
 };
 
 #define TIP_LINE_START gettext_noop("Let go of the button to complete the line.")
 #define TIP_SHAPE_START gettext_noop("Hold the button to stretch the shape.")
 #define TIP_SHAPE_NEXT gettext_noop("Move the mouse to rotate the shape. Click to draw it.")
-#define TIP_NEW_ABORT gettext_noop("Ok then... Let's keep drawing this one!")
+#define TIP_NEW_ABORT gettext_noop("OK then… Let’s keep drawing this one!")
 
 
 /* Tool icon filenames: */
